SCRIPT_NAME=i386go32
OUTPUT_FORMAT="coff-i386"
TEXT_START_ADDR=0x10a8
TARGET_PAGE_SIZE=0x1000
SEGMENT_SIZE=0x1000
NONPAGED_TEXT_START_ADDR=0x0
ARCH=i386

